==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ssm/kotlin/inputs/MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ssm.kotlin.inputs

import com.pulumi.aws.ssm.inputs.MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name The parameter name.
 * @property values The array of strings.
 */
public data class MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs(
    public val name: Output<String>,
    public val values: Output<List<String>>,
) :
    ConvertibleToJava<com.pulumi.aws.ssm.inputs.MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs> {
    override fun toJava():
        com.pulumi.aws.ssm.inputs.MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs =
        com.pulumi.aws.ssm.inputs.MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .values(values.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs].
 */
@PulumiTagMarker
public class MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgsBuilder
internal constructor() {
    private var name: Output<String>? = null

    private var values: Output<List<String>>? = null

    /**
     * @param value The parameter name.
     */
    @JvmName("efqrvbcvhykjntfw")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The array of strings.
     */
    @JvmName("tjewprfdfkyfewna")
    public suspend fun values(`value`: Output<List<String>>) {
        this.values = value
    }

    @JvmName("yasgbceibhfbftdq")
    public suspend fun values(vararg values: Output<String>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values The array of strings.
     */
    @JvmName("rwlhganwquvikvco")
    public suspend fun values(values: List<Output<String>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value The parameter name.
     */
    @JvmName("vljrrmdopblixqtg")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The array of strings.
     */
    @JvmName("jtplwjxhmeppatua")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values The array of strings.
     */
    @JvmName("lauhwgrsdtstnisr")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build():
        MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs =
        MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            values = values ?: throw PulumiNullFieldException("values"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ssm/kotlin/inputs/MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ssm.kotlin.inputs

import com.pulumi.aws.ssm.inputs.MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name The parameter name.
 * @property values The array of strings.
 */
public data class MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs(
    public val name: Output<String>,
    public val values: Output<List<String>>,
) :
    ConvertibleToJava<com.pulumi.aws.ssm.inputs.MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs> {
    override fun toJava(): com.pulumi.aws.ssm.inputs.MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs =
        com.pulumi.aws.ssm.inputs.MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .values(values.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs].
 */
@PulumiTagMarker
public class MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgsBuilder
internal constructor() {
    private var name: Output<String>? = null

    private var values: Output<List<String>>? = null

    /**
     * @param value The parameter name.
     */
    @JvmName("qdebgolvxjcuicoa")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The array of strings.
     */
    @JvmName("ouswkbllvkqqwvwx")
    public suspend fun values(`value`: Output<List<String>>) {
        this.values = value
    }

    @JvmName("dmkvibxemrasbrcv")
    public suspend fun values(vararg values: Output<String>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values The array of strings.
     */
    @JvmName("pwpintdrecrugomb")
    public suspend fun values(values: List<Output<String>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value The parameter name.
     */
    @JvmName("cbohulxccefelpnm")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The array of strings.
     */
    @JvmName("mvuhdvbqijeillus")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values The array of strings.
     */
    @JvmName("jffssffyftkknnww")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs =
        MaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameterArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            values = values ?: throw PulumiNullFieldException("values"),
        )
}
